package de.intevation.flys.artifacts.model;

import java.util.List;
import java.util.ArrayList;

import de.intevation.flys.backend.SessionFactoryProvider;

import de.intevation.flys.model.River;
import de.intevation.flys.model.Gauge;
import de.intevation.flys.model.Range;

import org.hibernate.SessionFactory;
import org.hibernate.Session;
import org.hibernate.Query;

public class GaugesFactory
{
    public static List<Gauge> getGauges(River river) {
        return getGauges(river.getName());
    }

    public static List<Gauge> getGauges(String river) {
        SessionFactory sf = SessionFactoryProvider.getSessionFactory();
        Session session = sf.openSession();
        try {
            Query query = session.createQuery(
                "from Gauge where river.name=:name");
            query.setParameter("name", river);
            return query.list();
        }
        finally {
            session.close();
        }
    }

    public static List<Gauge> filterRanges(
        List<Gauge>     gauges,
        List<double []> ranges
    ) {
        // XXX: Inefficent!
        ArrayList<Range> rs = new ArrayList<Range>();
        for (double [] range: ranges) {
            double a = range[0];
            double b = range[1];
            rs.add(new Range(Math.min(a, b), Math.max(a, b), null));
        }
        return filter(gauges, rs);
    }

    public static List<Gauge> filter(List<Gauge> gauges, List<Range> ranges) {
        // TODO: Make it an HQL filter!
        ArrayList<Gauge> out = new ArrayList<Gauge>();
        for (Gauge gauge: gauges) {
            Range range = gauge.getRange();
            for (Range cmp: ranges) {
                if (range.intersects(cmp)) {
                    out.add(gauge);
                    break;
                }
            }
        }
        return out;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
